@@ -56,18 +56,13 @@ class ElmaApiWebClient:
     __AuthTokenLiveTimestamp: float
     __SessionToken: str
     __AppToken: str
-    authorization: 'Authorization'
-    workflow: 'Workflow'
-    workflow_instance_service: 'WorkflowInstanceService'
 
     def __init__(self, host_name: str = "http://localhost", port: int = 8080, debug_mode=False) -> None:
         super().__init__()
         self.host_name = host_name
         self.port = port
         self.debug_mode = debug_mode
-        self.authorization = self.init_authorization()
-        self.workflow = self.init_workflow()
-        self.workflow_instance_service = self.init_workflow_instance_service()
+        self.__authorization = self.init_authorization()
 
     def init_authorization(self):
         return ElmaApiWebClient.Authorization(self)
@@ -83,7 +78,7 @@ class ElmaApiWebClient:
     def init_with_auth(host_name: str, port: int, debug_mode=False,
                        user_login: str = None, user_password: str = None, app_token: str = None):
         instance = ElmaApiWebClient(host_name=host_name, port=port, debug_mode=debug_mode)
-        auth_result = instance.authorization.login_with_user_name(user_login=user_login,
+        auth_result = instance.__authorization.login_with_user_name(user_login=user_login,
                                                                   user_password=user_password,
                                                                   app_token=app_token)
         instance.set_auth_token(auth_result.AuthToken)
@@ -155,7 +150,7 @@ class ElmaApiWebClient:
         tdelta = date_now - date_of_token_creation
         max_minutes_alive = (self.__AuthTokenMaxMinutesAlive - 1) * 60
         if tdelta.seconds >= max_minutes_alive:
-            auth_result = self.authorization.login_with_user_name(user_login=self.__UserLogin,
+            auth_result = self.__authorization.login_with_user_name(user_login=self.__UserLogin,
                                                                   user_password=self.__UserPassword,
                                                                   app_token=self.__AppToken)
             self.__AuthToken = auth_result.AuthToken
@@ -234,9 +229,9 @@ class ElmaApiWebClient:
     # API Methods:
 
     class ApiModule:
-        def __init__(self, elma: 'ElmaApiWebClient') -> None:
+        def __init__(self, elma_api_web_client: 'ElmaApiWebClient') -> None:
             super().__init__()
-            self.elma_client = elma
+            self.elma_client = elma_api_web_client
 
     class Authorization(ApiModule):
 
@@ -278,16 +273,25 @@ class ElmaApiWebClient:
                                                             body=json.dumps(json_body),
                                                             auth_token=auth_token, session_token=session_token)
 
-        def check_token(self, token) -> AuthResponse:
-            return AuthResponse.from_json(self.elma_client.base_get_request(path=check_token_path.format(token)))
+        def check_token(self, token) -> bool:
+            try:
+                self.elma_client.base_get_request(path=check_token_path.format(token))
+            except ElmaApiException:
+                return False
+            return True
+
+        def __parse_time(self, str_time: str):
+            return str_time.replace("/Date(", "").replace(")/", "")
 
         def server_time(self, auth_token: str = None, session_token: str = None) -> str:
-            return self.elma_client.authorized_get_request(path=server_time_path,
-                                                           auth_token=auth_token, session_token=session_token)
+            response: str = self.elma_client.authorized_get_request(path=server_time_path,
+                                                                    auth_token=auth_token, session_token=session_token)
+            return self.__parse_time(response)
 
         def server_time_utc(self, auth_token: str = None, session_token: str = None) -> str:
-            return self.elma_client.authorized_get_request(path=server_time_utc_path,
-                                                           auth_token=auth_token, session_token=session_token)
+            response = self.elma_client.authorized_get_request(path=server_time_utc_path,
+                                                               auth_token=auth_token, session_token=session_token)
+            return self.__parse_time(response)
 
         def temporary_guid(self, auth_token: str = None, session_token: str = None) -> str:
             return self.elma_client.authorized_get_request(path=temporary_guid_path,
