@@ -204,10 +204,29 @@ class HasDynamicFormRs(DataSerializable):
 class HasDynamicFormsRq(DataSerializable):
     TaskIds: list = None
 
+    def __init__(self, task_ids: list) -> None:
+        super().__init__()
+        self.TaskIds = []
+        for _id in task_ids:
+            self.TaskIds.append(HasDynamicFormsRq.ElementCls(_id))
+
+    @dataclass
+    class ElementCls(DataSerializable):
+        Id: int = None
+
 
 @dataclass
 class HasDynamicFormsRs(DataSerializable):
-    Result: list = None
+
+    @dataclass
+    class ElementCls(DataSerializable):
+        TaskId: int = None
+        IsDynamic: bool = None
+
+    HasDynamicForms: list = None
+
+    def __post_init__(self):
+        self.HasDynamicForms = init_list(self.HasDynamicForms, HasDynamicFormsRs.ElementCls)
 
 
 # TaskStandardOutputFlows
@@ -223,9 +242,11 @@ class TaskStandardOutputFlowsRs(DataSerializable):
         Uid: int = None
         Status: str = None
         Name: str = None
+        TypeUid: str = None
 
     Result: bool = None
     Flows: list = None
+    TypeUid: str = None
 
     def __post_init__(self):
         self.Flows = init_list(self.Flows, TaskStandardOutputFlowsRs.FlowCls)
